@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-08-25'; # DATE
+our $DATE = '2022-08-26'; # DATE
 our $DIST = 'Sah-Schemas-JSON'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 our $schema = [any => {
     summary => 'A data structure, coerced from JSON string',
@@ -50,7 +50,7 @@ Sah::Schema::any_from_json - A data structure, coerced from JSON string
 
 =head1 VERSION
 
-This document describes version 0.005 of Sah::Schema::any_from_json (from Perl distribution Sah-Schemas-JSON), released on 2022-08-25.
+This document describes version 0.006 of Sah::Schema::any_from_json (from Perl distribution Sah-Schemas-JSON), released on 2022-08-26.
 
 =head1 SYNOPSIS
 
@@ -92,12 +92,12 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = 1;
+ $data = {};
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "";
- my $errmsg = $validator->($data); # => "String is not a valid JSON: malformed JSON string, neither tag, array, object, number, string or atom, at character offset 0 (before \"(end of string)\") at (eval 2326) line 13.\n"
+ $data = "[1,2";
+ my $errmsg = $validator->($data); # => "String is not a valid JSON: , or ] expected while parsing array, at character offset 4 (before \"(end of string)\") at (eval 2364) line 13.\n"
 
 Often a schema has coercion rule or default value, so after validation the
 validated value is different. To return the validated (set-as-default, coerced,
@@ -107,12 +107,12 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = 1;
- my $res = $validator->($data); # => ["",1]
+ $data = {};
+ my $res = $validator->($data); # => ["",{}]
  
  # a sample invalid data
- $data = "";
- my $res = $validator->($data); # => ["String is not a valid JSON: malformed JSON string, neither tag, array, object, number, string or atom, at character offset 0 (before \"(end of string)\") at (eval 2332) line 13.\n",""]
+ $data = "[1,2";
+ my $res = $validator->($data); # => ["String is not a valid JSON: , or ] expected while parsing array, at character offset 4 (before \"(end of string)\") at (eval 2370) line 13.\n","[1,2"]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
