@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-08-25'; # DATE
+our $DATE = '2022-08-26'; # DATE
 our $DIST = 'Sah-Schemas-JSON'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 our $schema = [array => {
     summary => 'Array, coercible from JSON string',
@@ -18,6 +18,9 @@ string e.g. in a command-line script as command-line argument or option, the
 string will be coerced into array if the string contains a JSON-encoded array.
 Data will not be valid if the string does not contain valid JSON.
 
+Note that array data is accepted, unlike the `json_str::array` schema which only
+accepts JSON-encoded array in string form.
+
 _
     examples => [
         {value=>'', valid=>0, summary=>'Empty string is not a valid JSON'},
@@ -48,7 +51,7 @@ Sah::Schema::array_from_json - Array, coercible from JSON string
 
 =head1 VERSION
 
-This document describes version 0.005 of Sah::Schema::array_from_json (from Perl distribution Sah-Schemas-JSON), released on 2022-08-25.
+This document describes version 0.006 of Sah::Schema::array_from_json (from Perl distribution Sah-Schemas-JSON), released on 2022-08-26.
 
 =head1 SYNOPSIS
 
@@ -88,12 +91,12 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "[1,2,3,{}]";
+ $data = [];
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = {};
- my $errmsg = $validator->($data); # => "Not of type array"
+ $data = "[1,2";
+ my $errmsg = $validator->($data); # => "String is not a valid JSON: , or ] expected while parsing array, at character offset 4 (before \"(end of string)\") at (eval 2394) line 13.\n"
 
 Often a schema has coercion rule or default value, so after validation the
 validated value is different. To return the validated (set-as-default, coerced,
@@ -103,12 +106,12 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "[1,2,3,{}]";
- my $res = $validator->($data); # => ["",[1,2,3,{}]]
+ $data = [];
+ my $res = $validator->($data); # => ["",[]]
  
  # a sample invalid data
- $data = {};
- my $res = $validator->($data); # => ["Not of type array",{}]
+ $data = "[1,2";
+ my $res = $validator->($data); # => ["String is not a valid JSON: , or ] expected while parsing array, at character offset 4 (before \"(end of string)\") at (eval 2400) line 13.\n","[1,2"]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
@@ -178,6 +181,9 @@ string e.g. in a command-line script as command-line argument or option, the
 string will be coerced into array if the string contains a JSON-encoded array.
 Data will not be valid if the string does not contain valid JSON.
 
+Note that array data is accepted, unlike the C<json_str::array> schema which only
+accepts JSON-encoded array in string form.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-JSON>.
