@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-08-25'; # DATE
+our $DATE = '2022-08-26'; # DATE
 our $DIST = 'Sah-Schemas-JSON'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 our $schema = [hash => {
     summary => 'Hash, coerced from JSON string',
@@ -18,6 +18,9 @@ string e.g. in a command-line script as command-line argument or option, the
 string will be coerced into hash if the string contains a JSON-encoded object
 (hash). Data will not be valid if the string does not contain valid JSON.
 
+Note that hash data is accepted, unlike the `json_str::hash` schema which only
+accepts hash in JSON-encoded string form.
+
 _
     examples => [
         {value=>'', valid=>0, summary=>'Empty string is not a valid JSON'},
@@ -48,7 +51,7 @@ Sah::Schema::hash_from_json - Hash, coerced from JSON string
 
 =head1 VERSION
 
-This document describes version 0.005 of Sah::Schema::hash_from_json (from Perl distribution Sah-Schemas-JSON), released on 2022-08-25.
+This document describes version 0.006 of Sah::Schema::hash_from_json (from Perl distribution Sah-Schemas-JSON), released on 2022-08-26.
 
 =head1 SYNOPSIS
 
@@ -88,12 +91,12 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = {};
+ $data = "{\"a\":1,\"b\":2}";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "";
- my $errmsg = $validator->($data); # => "String is not a valid JSON: malformed JSON string, neither tag, array, object, number, string or atom, at character offset 0 (before \"(end of string)\") at (eval 2378) line 13.\n"
+ $data = [];
+ my $errmsg = $validator->($data); # => "Not of type hash"
 
 Often a schema has coercion rule or default value, so after validation the
 validated value is different. To return the validated (set-as-default, coerced,
@@ -103,12 +106,12 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = {};
- my $res = $validator->($data); # => ["",{}]
+ $data = "{\"a\":1,\"b\":2}";
+ my $res = $validator->($data); # => ["",{a=>1,b=>2}]
  
  # a sample invalid data
- $data = "";
- my $res = $validator->($data); # => ["String is not a valid JSON: malformed JSON string, neither tag, array, object, number, string or atom, at character offset 0 (before \"(end of string)\") at (eval 2384) line 13.\n",""]
+ $data = [];
+ my $res = $validator->($data); # => ["Not of type hash",[]]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
@@ -178,6 +181,9 @@ string e.g. in a command-line script as command-line argument or option, the
 string will be coerced into hash if the string contains a JSON-encoded object
 (hash). Data will not be valid if the string does not contain valid JSON.
 
+Note that hash data is accepted, unlike the C<json_str::hash> schema which only
+accepts hash in JSON-encoded string form.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-JSON>.
