@@ -3,9 +3,9 @@
 package Sah::Schemas::JSON;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-08-25'; # DATE
+our $DATE = '2022-08-26'; # DATE
 our $DIST = 'Sah-Schemas-JSON'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 1;
 # ABSTRACT: Various schemas related to JSON
@@ -22,7 +22,7 @@ Sah::Schemas::JSON - Various schemas related to JSON
 
 =head1 VERSION
 
-This document describes version 0.005 of Sah::Schemas::JSON (from Perl distribution Sah-Schemas-JSON), released on 2022-08-25.
+This document describes version 0.006 of Sah::Schemas::JSON (from Perl distribution Sah-Schemas-JSON), released on 2022-08-26.
 
 =head1 SAH SCHEMAS
 
@@ -50,6 +50,9 @@ string e.g. in a command-line script as command-line argument or option, the
 string will be coerced into array if the string contains a JSON-encoded array.
 Data will not be valid if the string does not contain valid JSON.
 
+Note that array data is accepted, unlike the C<json_str::array> schema which only
+accepts JSON-encoded array in string form.
+
 
 =item * L<hash_from_json|Sah::Schema::hash_from_json>
 
@@ -60,6 +63,9 @@ string e.g. in a command-line script as command-line argument or option, the
 string will be coerced into hash if the string contains a JSON-encoded object
 (hash). Data will not be valid if the string does not contain valid JSON.
 
+Note that hash data is accepted, unlike the C<json_str::hash> schema which only
+accepts hash in JSON-encoded string form.
+
 
 =item * L<json_or_str|Sah::Schema::json_or_str>
 
@@ -88,6 +94,33 @@ array) but you know that the string contains a valid JSON. Data will not be
 valid if the string does not contain valid JSON.
 
 
+=item * L<json_str::array|Sah::Schema::json_str::array>
+
+A string that contains valid JSON and the JSON encodes an array.
+
+This schema is like the C<json_str> schema: it accepts a string that contains
+valid JSON. The JSON string will not be decoded but you know that the string
+contains a valid JSON. In addition to that, the JSON must encode an array. Data
+will not be valid if it is not a valid JSON or if the JSON is not an array.
+
+Note that unlike the C<array_from_json> schema, an array data is not accepted by
+this schema. Data must be a string.
+
+
+=item * L<json_str::hash|Sah::Schema::json_str::hash>
+
+A string that contains valid JSON and the JSON encodes a hash (JavaScript object).
+
+This schema is like the C<json_str> schema: it accepts a string that contains
+valid JSON. The JSON string will not be decoded but you know that the string
+contains a valid JSON. In addition to that, the JSON must encode a hash
+(JavaScript object). Data will not be valid if it is not a valid JSON or if the
+JSON is not a hash.
+
+Note that unlike the C<hash_from_json> schema, a hash data is not accepted by
+this schema. Data must be a string.
+
+
 =back
 
 =head1 HOMEPAGE
@@ -100,6 +133,8 @@ Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-JSON>.
 
 =head1 SEE ALSO
 
+L<Sah::Schemas::Str>
+
 L<Sah> - schema specification
 
 L<Data::Sah> - Perl implementation of Sah
